DATA_SECTION
  init_number Rsd
  init_int Nprojectyears
  init_number projectcatch  
  init_number Smean
  init_number Ssigma
  init_number Rmean
  init_number Rsigma
  init_int qtype
  init_number qlb  //note need to change depending on type
  init_number qub  //note need to change depending on type  
  //init_number S
  init_number sigma
  init_int Nyears
  init_vector C(1,Nyears)
  init_int Nobs
  init_matrix CPUE(1,Nobs,1,2)
  vector Rdev(Nyears+1,Nyears+Nprojectyears+1)
  !!rec_seed=1211;
PARAMETER_SECTION
  init_bounded_number S(0,1,2) 
  init_bounded_number R(1,1000) 
  init_bounded_number q(qlb,qub)
  number qtemp
  likeprof_number Rtemp  
  vector N(1,Nyears+1+Nprojectyears)
  objective_function_value f
PROCEDURE_SECTION
  f=0;
  dynamics();
  likelihood();
  if (mceval_phase()) decision();
  Rtemp=R;

FUNCTION dynamics
  N(1)=R/(1-S);
  for(int year=1;year<=Nyears;year++)
  {
	N(year+1)=S*N(year)+R-C(year);
  }

FUNCTION likelihood
  if (qtype==0) qtemp=q;
  else qtemp=exp(q);
  for(int obs=1;obs<=Nobs;obs++)
  {
	f+= 0.5*square((log(CPUE(obs,2))-log(N(CPUE(obs,1))*qtemp) ) / sigma);	
  }
  f+=0.5*square((R-Rmean) / (Rsigma));
  f+=0.5*square((S-Smean) / (Ssigma));

FUNCTION decision
  Rdev.fill_randn_ni(rec_seed);
  for(int year=Nyears+1;year<=Nyears+Nprojectyears;year++)
  {
	N(year+1)=S*N(year)+R*mfexp(Rdev(year+1)*Rsd-0.5*Rsd*Rsd)-projectcatch;
	if (N(year+1)<=0) 
	{
		N(year+1)=0;
	}
  }
  ofstream out("posterior.dat",ios::app);
  out<<R<<" "<<q<<" "<<N(1)<<" "<<N(Nyears+1)<<" "<<N(Nyears+Nprojectyears+1)<<" "<<Rdev(Nyears+Nprojectyears)<<"\n";
  out.close();


REPORT_SECTION
  report<<N<<endl;

GLOBALS_SECTION
  long int rec_seed;

